==> igniteui-react-core-18.0.0.tgz: package/esm5/lib/ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelTemplateHeightRequestedEventArgsDescription } from "./ListPanelTemplateHeightRequestedEventArgsDescription";
/**
 * @hidden
 */
var ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata, _super);
    function ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.b = function (a) {
        if (ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a == null) {
            ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.c(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
        }
        if (a.g(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
    };
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.c = function (a) {
        a.item("DataRow", "Number:int");
        a.item("DataItemRef", "(w:DataItem,wf:DataItem)DataRef");
        a.item("Height", "Number:double");
    };
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.d = function (a) {
        ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.b(a);
        a.u("ListPanelTemplateHeightRequestedEventArgs", function () { return new ListPanelTemplateHeightRequestedEventArgsDescription(); });
        a.t("ListPanelTemplateHeightRequestedEventArgs", ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
    };
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.$t = markType(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata, 'ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata');
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata;
}(Base));
export { ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelTemplateHeightRequestedEventArgsDescription } from "./ListPanelTemplateHeightRequestedEventArgsDescription";
/**
 * @hidden
 */
var ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata, _super);
    function ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.b = function (a) {
        if (ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a == null) {
            ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.c(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
        }
        if (a.j(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
    };
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.c = function (a) {
        a.item("DataRow", "Number:int");
        a.item("DataItemRef", "(w:DataItem,wf:DataItem)DataRef");
        a.item("Height", "Number:double");
    };
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.d = function (a) {
        ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.b(a);
        a.aa("ListPanelTemplateHeightRequestedEventArgs", function () { return new ListPanelTemplateHeightRequestedEventArgsDescription(); });
        a.z("ListPanelTemplateHeightRequestedEventArgs", ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
    };
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.$t = markType(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata, 'ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata');
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata;
}(Base));
export { ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata };
